# -*- coding: utf-8 -*-
"""
Enterprise Integrated Channel Django application initialization.
"""

from django.apps import AppConfig


class IntegratedChannelConfig(AppConfig):
    """
    Configuration for the Enterprise Integrated Channel Django application.
    """
    name = 'integrated_channels.integrated_channel'
    verbose_name = "Enterprise Integrated Channels"
