# -*- coding: utf-8 -*-
"""
The Canvas Integrated Channel package.
"""

__version__ = "0.0.1"

default_app_config = ("integrated_channels.canvas.apps."  # pylint: disable=invalid-name
                      "CanvasConfig")
