# -*- coding: utf-8 -*-
"""
Enterprise Integrated Channel Moodle Django application initialization.
"""

from django.apps import AppConfig


class MoodleConfig(AppConfig):
    """
    Configuration for the Enterprise Integrated Channel Moodle Django application.
    """
    name = 'integrated_channels.moodle'
    verbose_name = 'Enterprise Moodle Integration'
